@@ -1,5 +1,6 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* GNOME panel mail check module.
- * (C) 1997, 1998, 1999 The Free Software Foundation
+ * (C) 1997, 1998, 1999, 2000 The Free Software Foundation
  *
  * Authors: Miguel de Icaza
  *          Jacob Berkman
@@ -17,7 +18,7 @@
 #include <config.h>
 #include <gnome.h>
 #include <applet-widget.h>
-#include <gdk_imlib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "popcheck.h"
 #include "mailcheck.h"
@@ -107,6 +108,9 @@ struct _MailCheck {
 	GtkWidget *newmail_cmd_entry, *newmail_cmd_check;
 	GtkWidget *clicked_cmd_entry, *clicked_cmd_check;
 
+	/* the about box */
+	GtkWidget *about;
+
 	gboolean anim_changed;
 
 	char *mailcheck_text_only;
@@ -128,6 +132,8 @@ struct _MailCheck {
 	int size;
 };
 
+static int mail_check_timeout (gpointer data);
+
 #define WANT_BITMAPS(x) (x == REPORT_MAIL_USE_ANIMATION || x == REPORT_MAIL_USE_BITMAP)
 
 static void close_callback (GtkWidget *widget, void *data);
@@ -172,6 +178,31 @@ calc_dir_contents (char *dir) {
        return size;
 }
 
+static void
+get_password_callback (gchar *string, gpointer data)
+{
+	gchar **pass = (gchar **)data;
+
+	*pass = string;
+
+	gtk_main_quit();
+}
+
+static gchar *
+get_remote_password ()
+{
+	gchar *pass;
+	GtkWidget *dialog;
+
+	dialog = gnome_request_dialog(TRUE, _("Password:"), "",
+				      256, get_password_callback, &pass, NULL);
+	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
+	gtk_widget_show(dialog);
+	gtk_main();
+
+	return pass;
+}
+
 /*
  * Get file modification time, based upon the code
  * of Byron C. Darrah for coolmail and reused on fvwm95
@@ -183,16 +214,39 @@ check_mail_file_status (MailCheck *mc)
 	struct stat s;
 	off_t newsize;
 	int status, old_unreadmail;
+	static gchar *pass = NULL;
 	
 	if ((mc->mailbox_type == MAILBOX_POP3) || 
 	    (mc->mailbox_type == MAILBOX_IMAP)) {
 		int v;
-		
-		if (mc->mailbox_type == MAILBOX_POP3)
-			v = pop3_check(mc->remote_server, mc->remote_username, mc->remote_password);
+
+		if (mc->remote_password != NULL &&
+		    mc->remote_password[0] != '\0') {
+			if(pass && pass != mc->remote_password)
+				g_free(pass);
+			pass = mc->remote_password;
+		}
+		else if(pass == NULL) {
+			gtk_timeout_remove(mc->mail_timeout);
+			pass = get_remote_password();
+			mc->mail_timeout = gtk_timeout_add(mc->update_freq,
+							   mail_check_timeout,
+							   mc);
+		}
+
+		if (pass && mc->remote_username && mc->remote_server) {
+			if (mc->mailbox_type == MAILBOX_POP3)
+				v = pop3_check(mc->remote_server,
+					       mc->remote_username,
+					       pass);
+			else
+				v = imap_check(mc->remote_server,
+					       mc->remote_username,
+					       pass);
+		}
 		else
-			v = imap_check(mc->remote_server, mc->remote_username, mc->remote_password);
-		
+			v = -1;
+
 		if (v == -1) {
 #if 0
 			/* don't notify about an error: think of people with
@@ -207,71 +261,91 @@ check_mail_file_status (MailCheck *mc)
 			mc->mailbox_type = MAILBOX_LOCAL;
 			mc->anymail = mc->newmail = 0;
 #endif
-		} else {
-		  old_unreadmail = mc->unreadmail;
-		  mc->unreadmail = (signed int) (((unsigned int) v) >> 16);
-		  if(mc->unreadmail > 0 && old_unreadmail != mc->unreadmail)
-		    mc->newmail = 1;
-		  else
-		    mc->newmail = 0;
-		  mc->anymail = (signed int) (((unsigned int) v) & 0x0000FFFFL) ? 1 : 0;
+		}
+		else {
+			old_unreadmail = mc->unreadmail;
+			mc->unreadmail = (signed int) (((unsigned int) v) >> 16);
+			if(mc->unreadmail > 0 && old_unreadmail != mc->unreadmail)
+				mc->newmail = 1;
+			else
+				mc->newmail = 0;
+			mc->anymail = (signed int) (((unsigned int) v) & 0x0000FFFFL) ? 1 : 0;
 		} 
-	} else if(mc->mailbox_type == MAILBOX_LOCAL) {
-	    status = stat (mc->mail_file, &s);
-	    if (status < 0) {
-	      oldsize = 0;
-	      mc->anymail = mc->newmail = mc->unreadmail = 0;
-	      return;
-	    }
+	}
+	else if (mc->mailbox_type == MAILBOX_LOCAL) {
+		status = stat (mc->mail_file, &s);
+		if (status < 0) {
+			oldsize = 0;
+			mc->anymail = mc->newmail = mc->unreadmail = 0;
+			return;
+		}
 		
-	    newsize = s.st_size;
-	    mc->anymail = newsize > 0;
-	    mc->unreadmail = (s.st_mtime >= s.st_atime && newsize > 0);
+		newsize = s.st_size;
+		mc->anymail = newsize > 0;
+		mc->unreadmail = (s.st_mtime >= s.st_atime && newsize > 0);
 		
-	    if (newsize != oldsize && mc->unreadmail)
-	      mc->newmail = 1;
-	    else
-	      mc->newmail = 0;
+		if (newsize != oldsize && mc->unreadmail)
+			mc->newmail = 1;
+		else
+			mc->newmail = 0;
 		
-	    oldsize = newsize;
+		oldsize = newsize;
 	}
 	else { /* MAILBOX_LOCALDIR */
-	  int newmail, oldmail;
-	  char tmp[1024];
-	  snprintf(tmp, 1024, "%s/new", mc->mail_file);
-	  newmail = calc_dir_contents(tmp);
-	  snprintf(tmp, 1024, "%s/cur", mc->mail_file);
-	  oldmail = calc_dir_contents(tmp);
-	  mc->newmail = newmail > oldsize;
-	  mc->unreadmail = newmail;
-	  oldsize = newmail;
-	  mc->anymail = newmail || oldmail;
+		int newmail, oldmail;
+		char tmp[1024];
+		snprintf(tmp, 1024, "%s/new", mc->mail_file);
+		newmail = calc_dir_contents(tmp);
+		snprintf(tmp, 1024, "%s/cur", mc->mail_file);
+		oldmail = calc_dir_contents(tmp);
+		mc->newmail = newmail > oldsize;
+		mc->unreadmail = newmail;
+		oldsize = newmail;
+		mc->anymail = newmail || oldmail;
 	}	    
 }
 
-static void
+static gboolean
 mailcheck_load_animation (MailCheck *mc, char *fname)
 {
 	int width, height;
-	GdkImlibImage *im;
+	int pbwidth, pbheight;
+	GdkPixbuf *pb;
 
-	im = gdk_imlib_load_image (fname);
+	if(mc->email_pixmap)
+		gdk_pixmap_unref(mc->email_pixmap);
+	if(mc->email_mask)
+		gdk_bitmap_unref(mc->email_mask);
+	mc->email_pixmap = NULL;
+	mc->email_mask = NULL;
+
+	pb = gdk_pixbuf_new_from_file (fname);
+	if(!pb)
+		return FALSE;
+
+	pbwidth = gdk_pixbuf_get_width(pb);
+	pbheight = gdk_pixbuf_get_height(pb);
 
 	height = mc->size;
-	width = im->rgb_width*((double)height/im->rgb_height);
+	width = pbwidth*((double)height/pbheight);
 
-	gdk_imlib_render (im, width, height);
-
-	mc->email_pixmap = gdk_imlib_copy_image (im);
-	mc->email_mask = gdk_imlib_copy_mask (im);
-
-	gdk_imlib_destroy_image (im);
-	
 	/* yeah, they have to be square, in case you were wondering :-) */
 	mc->frames = width / height;
-	if (mc->frames == 3)
+	if (mc->frames < 3)
+		return FALSE;
+	else if (mc->frames == 3)
 		mc->report_mail_mode = REPORT_MAIL_USE_BITMAP;
 	mc->nframe = 0;
+
+
+	gdk_pixbuf_render_pixmap_and_mask(pb,
+					  &mc->email_pixmap,
+					  &mc->email_mask,
+					  128);
+
+	gdk_pixbuf_unref (pb);
+	
+	return TRUE;
 }
 
 static int
@@ -404,7 +478,9 @@ mailcheck_destroy (GtkWidget *widget, gpointer data)
 	mc->bin = NULL;
 
 	if (mc->property_window)
-		close_callback (NULL, mc);
+		gtk_widget_destroy(mc->property_window);
+	if (mc->about)
+		gtk_widget_destroy(mc->about);
 
 	g_free (mc->pre_check_cmd);
 	g_free (mc->newmail_cmd);
@@ -413,8 +489,15 @@ mailcheck_destroy (GtkWidget *widget, gpointer data)
 	g_free(mc->remote_server);
 	g_free(mc->remote_username);
 	g_free(mc->remote_password);
-                
+
+	if(mc->email_pixmap)
+		gdk_pixmap_unref(mc->email_pixmap);
+	if(mc->email_mask)
+		gdk_bitmap_unref(mc->email_mask);
+
 	gtk_timeout_remove (mc->mail_timeout);
+
+	g_free(mc);
 }
 
 static GtkWidget *
@@ -461,8 +544,8 @@ create_mail_widgets (MailCheck *mc)
 	gtk_widget_show (mc->label);
 	gtk_widget_ref (mc->label);
 	
-	if (fname && WANT_BITMAPS (mc->report_mail_mode)) {
-		mailcheck_load_animation (mc,fname);
+	if (fname && WANT_BITMAPS (mc->report_mail_mode) &&
+	    mailcheck_load_animation (mc, fname)) {
 		mc->containee = mc->da;
 	} else {
 		mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
@@ -571,7 +654,6 @@ static void
 close_callback (GtkWidget *widget, gpointer data)
 {
 	MailCheck *mc = data;
-	gtk_widget_destroy (mc->property_window);
 	mc->property_window = NULL;
 }
 
@@ -584,19 +666,26 @@ load_new_pixmap (MailCheck *mc)
 	if (mc->selected_pixmap_name == mc->mailcheck_text_only) {
 		mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
 		mc->containee = mc->label;
-		if(mc->animation_file) g_free(mc->animation_file);
+		g_free(mc->animation_file);
 		mc->animation_file = NULL;
 	} else {
-		char *fname = g_strconcat ("mailcheck/", mc->selected_pixmap_name, NULL);
+		char *fname = g_strconcat ("mailcheck/",
+					   mc->selected_pixmap_name, NULL);
 		char *full;
 		
-		full = gnome_unconditional_pixmap_file (fname);
+		full = gnome_pixmap_file (fname);
 		free (fname);
 		
-		mailcheck_load_animation (mc,full);
-		mc->containee = mc->da;
-		if(mc->animation_file) g_free(mc->animation_file);
-		mc->animation_file = full;
+		if(full && mailcheck_load_animation (mc, full)) {
+			mc->containee = mc->da;
+			g_free(mc->animation_file);
+			mc->animation_file = full;
+		} else {
+			mc->report_mail_mode = REPORT_MAIL_USE_TEXT;
+			mc->containee = mc->label;
+			g_free(mc->animation_file);
+			mc->animation_file = NULL;
+		}
 	}
 	mail_check_timeout (mc);
 	gtk_widget_set_uposition (GTK_WIDGET (mc->containee), 0, 0);
@@ -617,8 +706,11 @@ apply_properties_callback (GtkWidget *widget, gint page, gpointer data)
 	/* do this here since we can no longer make the seconds
 	 * minimum 1
 	 */
-	if (mc->update_freq == 0)
-		mc->update_freq = 1000;
+	if (mc->update_freq == 0) {
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->sec_spin), 0.0);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON (mc->min_spin), 1.0);
+		mc->update_freq = 60*1000;
+	}
 
 	gtk_timeout_remove (mc->mail_timeout);
 	mc->mail_timeout = gtk_timeout_add (mc->update_freq, mail_check_timeout, mc);
@@ -998,18 +1090,21 @@ mailcheck_properties_page (MailCheck *mc)
 	return vbox;
 }
 
+static void
+phelp_cb (GtkWidget *w, gint tab, gpointer data)
+{
+	GnomeHelpMenuEntry help_entry = { "mailcheck_applet",
+					  "index.html#mailcheck-prefs" };
+	gnome_help_display(NULL, &help_entry);
+}	
+
 static void
 mailcheck_properties (AppletWidget *applet, gpointer data)
 {
-        static GnomeHelpMenuEntry help_entry = {
-		NULL, "properties-mailcheck"
-	};
 	GtkWidget *p;
 
 	MailCheck *mc = data;
 
-	help_entry.name = gnome_app_id;
-
 	if (mc->property_window != NULL) {
 		gdk_window_raise(mc->property_window->window);
 		return; /* Only one instance of the properties dialog! */
@@ -1031,8 +1126,7 @@ mailcheck_properties (AppletWidget *applet, gpointer data)
 	gtk_signal_connect (GTK_OBJECT (mc->property_window), "destroy",
 			    GTK_SIGNAL_FUNC(close_callback), mc);
 	gtk_signal_connect (GTK_OBJECT (mc->property_window), "help",
-			    GTK_SIGNAL_FUNC(gnome_help_pbox_display),
-			    &help_entry);
+			    GTK_SIGNAL_FUNC(phelp_cb), NULL);
 
 	gtk_widget_show (mc->property_window);
 }
@@ -1080,7 +1174,7 @@ applet_save_session(GtkWidget *w,
 static void
 mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 {
-	static GtkWidget *about = NULL;
+	MailCheck *mc = a_data;
 	static const gchar     *authors [] =
 	{
 		"Miguel de Icaza <miguel@kernel.org>",
@@ -1090,21 +1184,21 @@ mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 		NULL
 	};
 
-	if (about != NULL)
+	if (mc->about != NULL)
 	{
-		gdk_window_show(about->window);
-		gdk_window_raise(about->window);
+		gtk_widget_show_now(mc->about);
+		gdk_window_raise(mc->about->window);
 		return;
 	}
 	
-	about = gnome_about_new ( _("Mail check Applet"), "1.0",
-				  _("(c) 1998 the Free Software Foundation"),
-				  authors,
-				  _("Mail check notifies you when new mail is on your mailbox"),
-				  NULL);
-	gtk_signal_connect( GTK_OBJECT(about), "destroy",
-			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
-	gtk_widget_show(about);
+	mc->about = gnome_about_new ( _("Mail check Applet"), "1.1",
+				      _("(c) 1998-2000 the Free Software Foundation"),
+				      authors,
+				      _("Mail check notifies you when new mail is on your mailbox"),
+				      NULL);
+	gtk_signal_connect( GTK_OBJECT(mc->about), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &mc->about );
+	gtk_widget_show(mc->about);
 }
 
 /*this is when the panel size changes */
@@ -1128,9 +1222,9 @@ applet_change_pixel_size(GtkWidget * w, int size, gpointer data)
 }
 
 static void
-help_cb (AppletWidget *widget, gpointer data)
+help_callback (AppletWidget *widget, gpointer data)
 {
-	GnomeHelpMenuEntry help_ref = { "mailcheck", "index.html"};
+	GnomeHelpMenuEntry help_ref = { "mailcheck_applet", "index.html"};
 	gnome_help_display (NULL, &help_ref);
 }
 
@@ -1142,7 +1236,13 @@ make_mailcheck_applet(const gchar *goad_id)
 	char *emailfile;
 	char *query;
 
-	mc = g_new0(MailCheck,1);
+	applet = applet_widget_new(goad_id);
+	if (!applet) {
+		g_warning(_("Can't create applet!\n"));
+		return NULL;
+	}
+
+	mc = g_new0(MailCheck, 1);
 	mc->animation_tag = -1;
 	mc->animation_file = NULL;
 	mc->property_window = NULL;
@@ -1152,10 +1252,6 @@ make_mailcheck_applet(const gchar *goad_id)
 	/*initial state*/
 	mc->report_mail_mode = REPORT_MAIL_USE_ANIMATION;
 
-	applet = applet_widget_new(goad_id);
-	if (!applet)
-		g_error(_("Can't create applet!\n"));
-
 	gnome_config_push_prefix(APPLET_WIDGET(applet)->privcfgpath);
 
 	mc->mail_file = gnome_config_get_string("mail/mail_file");
@@ -1235,15 +1331,14 @@ make_mailcheck_applet(const gchar *goad_id)
 					      "help",
 					      GNOME_STOCK_PIXMAP_HELP,
 					      _("Help"),
-					      help_cb,
+					      help_callback,
 					      NULL);
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
 					      "about",
 					      GNOME_STOCK_MENU_ABOUT,
 					      _("About..."),
 					      mailcheck_about,
-					      NULL);	
-
+					      mc);	
 
 	gtk_widget_show (applet);
 	return applet;
