@@ -20,15 +20,20 @@
 #include <config.h>
 #include <gnome.h>
 #include "splash.h"
+#include "manager.h"
 
 typedef struct {
   GtkWidget *dialog;
   GtkWidget *progressbar;
   GtkWidget *label;
   gfloat max;
+  gint timeout;
 } SplashData;
 static SplashData *sd = NULL;
 
+#define SPLASHING (gnome_config_get_bool (GSM_OPTION_CONFIG_PREFIX SPLASH_SCREEN_KEY"="SPLASH_SCREEN_DEFAULT))
+#define HINTING (gnome_config_get_bool ("Gnome/Login/RunHints=true"))
+
 static gboolean
 destroy_dialog (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
@@ -36,20 +41,46 @@ destroy_dialog (GtkWidget *w, GdkEventButton *event, gpointer data)
   return TRUE;
 }
 
+static void
+hint ()
+{
+  char *cmd[] = { "gnome-hint", NULL };
+  g_message ("about to hint: %d", HINTING);
+  if (HINTING)
+    gnome_execute_async (NULL, 1, cmd);
+}
+
 static gboolean
 splash_cleanup (GtkObject *o, gpointer data)
 {
   g_free (sd);
   sd = NULL;
+  hint ();
+  return FALSE;
+}
+
+static gint
+timeout_cb (gpointer data)
+{
+  if (sd && sd->dialog)
+    gtk_widget_destroy (sd->dialog);
+
   return FALSE;
 }
 
 void
 stop_splash ()
 {
-  if (!sd)
+  if (!SPLASHING) {
+    hint ();
     return;
-  gtk_widget_destroy (sd->dialog);
+  }
+
+  if (!sd || sd->timeout)
+    return;
+
+  update_splash (_("done"), sd->max);
+  sd->timeout = gtk_timeout_add (2000, timeout_cb, NULL);
 }
 
 static void
@@ -59,7 +90,16 @@ window_realize (GtkWidget *win)
      be on top of the hints which are at WIN_LAYER_ONTOP,
      in fact, the splash screen is only temporary and should
      be above everything */
-  gnome_win_hints_set_layer(win,WIN_LAYER_ABOVE_DOCK);
+  gnome_win_hints_set_layer (win, WIN_LAYER_ABOVE_DOCK);
+  gdk_window_set_decorations (win->window, 0);
+  gnome_win_hints_set_state (win, 
+			     WIN_STATE_STICKY |
+			     WIN_STATE_FIXED_POSITION);
+  gnome_win_hints_set_hints (win, 
+			     WIN_HINTS_SKIP_FOCUS |
+			     WIN_HINTS_SKIP_WINLIST |
+			     WIN_HINTS_SKIP_TASKBAR);
+			     
 }
 
 void
@@ -75,8 +115,9 @@ start_splash (gfloat max)
   sd = g_malloc (sizeof (SplashData));
 
   sd->max = max;
-  
-  sd->dialog = gtk_window_new (GTK_WINDOW_POPUP);
+  sd->timeout=0;
+
+  sd->dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_position (GTK_WINDOW (sd->dialog),
 			   GTK_WIN_POS_CENTER);
   gtk_window_set_policy (GTK_WINDOW (sd->dialog),
@@ -134,7 +175,7 @@ update_splash (const gchar *text, gfloat priority)
     return;
   }
 
-  msg = g_strdup_printf (_("Starting GNOME: %s"), text);
+  msg = g_strdup_printf (_("Starting GNOME... %s"), text);
   
   gtk_label_set_text (GTK_LABEL (sd->label), msg);
   g_free (msg);
