@@ -2,6 +2,7 @@
  *
  *   Copyright (C) 1999 Free Software Foundation
  *   Copyright 2000 Helix Code, Inc.
+ *   Copyright 2000 Eazel, Inc.
  *   Authors: George Lebl <jirka@5z.com>
  *            Jacob Berkman <jacob@helixcode.com>
  *
@@ -45,7 +46,10 @@
 #include <libart_lgpl/art_affine.h>
 #include "nothing.cP"
 
-static GlobalConfig global_config;
+/* panel-util makes references to this, so yes this is UGLY UGLY UGLY to make
+ * it available, but we're not using those parts, so we just want the compiler
+ * to shut up */
+GlobalConfig global_config;
 static GlobalConfig loaded_config;
 
 /* animation page */
@@ -407,9 +411,11 @@ icon_notebook_page(int i)
 	
 	/* image file entry widgets */
 	entry_up[i] = create_icon_entry(table,"tile_file",0, 1,
-					_("Normal Tile"),
+					_("Normal tile"),
 					global_config.tile_up[i],
 					NULL);
+	gnome_icon_entry_set_pixmap_subdir(GNOME_ICON_ENTRY(entry_up[i]),
+					   "tiles");
 	w = gnome_icon_entry_gtk_entry (GNOME_ICON_ENTRY (entry_up[i]));
 	gtk_signal_connect_while_alive(GTK_OBJECT(w), "changed",
 				       GTK_SIGNAL_FUNC(changed_cb), 
@@ -417,9 +423,11 @@ icon_notebook_page(int i)
 				       GTK_OBJECT(capplet));
 
 	entry_down[i] = create_icon_entry(table,"tile_file",1, 2,
-					  _("Clicked Tile"),
+					  _("Clicked tile"),
 					  global_config.tile_down[i],
 					  NULL);
+	gnome_icon_entry_set_pixmap_subdir(GNOME_ICON_ENTRY(entry_down[i]),
+					   "tiles");
 	w = gnome_icon_entry_gtk_entry (GNOME_ICON_ENTRY (entry_down[i]));
 	gtk_signal_connect_while_alive(GTK_OBJECT(w), "changed",
 				       GTK_SIGNAL_FUNC(changed_cb), 
@@ -469,7 +477,7 @@ buttons_notebook_page (void)
 	  gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
 	  gtk_widget_show (box);
 
-	  label = gtk_label_new (_("Button Type: "));
+	  label = gtk_label_new (_("Button type: "));
 	  gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
 	  gtk_widget_show (label);
 
@@ -601,7 +609,7 @@ applets_notebook_page (void)
 			    GTK_SIGNAL_FUNC (changed_cb), NULL);
 	gtk_box_pack_start (GTK_BOX (box), movement_type_push_rb, FALSE, FALSE, 0);	
 
-	box = make_int_scale_box(_("Applet padding"),
+	box = make_int_scale_box(_("Padding"),
 				 &applet_padding,
 				 0.0, 10.0, 1.0);
 	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
@@ -731,7 +739,7 @@ menu_notebook_page(void)
 	gtk_table_attach_defaults(GTK_TABLE(table),use_large_icons_cb, 0,1,0,1);
 
 	/* Menu frame */
-	frame = gtk_frame_new (_("Panel menu"));
+	frame = gtk_frame_new (_("Global menu"));
 	gtk_container_set_border_width(GTK_CONTAINER (frame), GNOME_PAD_SMALL);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 	
@@ -1026,7 +1034,7 @@ loadup_vals(void)
 		gnome_config_get_bool("show_dot_buttons=FALSE");
 
 	global_config.hungry_menus =
-		gnome_config_get_bool("really_hungry_menus=FALSE");
+		gnome_config_get_bool("memory_hungry_menus=FALSE");
 
 	global_config.use_large_icons =
 		gnome_config_get_bool("use_large_icons=TRUE");
@@ -1088,7 +1096,7 @@ loadup_vals(void)
 	global_config.hide_panel_frame = gnome_config_get_bool("hide_panel_frame=FALSE");
 	global_config.tile_when_over = gnome_config_get_bool("tile_when_over=FALSE");
 	global_config.saturate_when_over = gnome_config_get_bool("saturate_when_over=TRUE");
-	
+	global_config.confirm_panel_remove = gnome_config_get_bool("confirm_panel_remove=TRUE");
 
 	for(i=0;i<LAST_TILE;i++) {
 		g_string_sprintf(buf,"tiles_enabled_%d=FALSE",i);
@@ -1156,7 +1164,7 @@ write_config(GlobalConfig *conf)
 			      conf->tooltips_enabled);
 	gnome_config_set_bool("show_dot_buttons",
 			      conf->show_dot_buttons);
-	gnome_config_set_bool("hungry_menus",
+	gnome_config_set_bool("memory_hungry_menus",
 			      conf->hungry_menus);
 	gnome_config_set_bool("use_large_icons",
 			      conf->use_large_icons);
@@ -1180,6 +1188,8 @@ write_config(GlobalConfig *conf)
 			      conf->tile_when_over);
 	gnome_config_set_bool("saturate_when_over",
 			      conf->saturate_when_over);
+	gnome_config_set_bool("confirm_panel_remove",
+			      conf->confirm_panel_remove);
 	gnome_config_set_int("menu_flags", conf->menu_flags);
 	gnome_config_set_bool("keys_enabled", conf->keys_enabled);
 	gnome_config_set_string("menu_key", conf->menu_key);
@@ -1255,7 +1265,7 @@ setup_the_ui(GtkWidget *capplet)
 	/* applet settings */
 	page = applets_notebook_page ();
 	gtk_notebook_append_page (GTK_NOTEBOOK (nbook),
-				  page, gtk_label_new (_("Applets")));
+				  page, gtk_label_new (_("Panel Objects")));
 
 	/* Menu notebook page */
 	page = menu_notebook_page ();
