@@ -1,6 +1,7 @@
 /*
  * GNOME panel launcher module.
- * (C) 1997 The Free Software Foundation
+ * (C) 1997,1998,1999,2000 The Free Software Foundation
+ * (C) 2000 Eazel, Inc.
  *
  * Authors: Miguel de Icaza
  *          Federico Mena
@@ -52,7 +53,8 @@ launch (Launcher *launcher, int argc, char *argv[])
 					    NULL);
 		gtk_window_set_wmclass(GTK_WINDOW(dlg),
 				       "no_exec_dialog","Panel");
-		gtk_widget_show_all(dlg);
+		gtk_widget_show_all (dlg);
+		panel_set_dialog_layer (dlg);
 		return;
 	}
 	
@@ -471,6 +473,9 @@ create_properties_dialog(Launcher *launcher)
 	gtk_signal_connect(GTK_OBJECT(dialog), "apply",
 			   GTK_SIGNAL_FUNC(properties_apply_callback),
 			   launcher);
+	gtk_signal_connect(GTK_OBJECT(dialog), "help",
+			   GTK_SIGNAL_FUNC(panel_pbox_help_cb),
+			   "launchers.html");
 
 	return dialog;
 }
@@ -516,6 +521,9 @@ load_launcher_applet_full (char *params, GnomeDesktopEntry *dentry,
 	applet_add_callback(applets_last->data,"properties",
 			    GNOME_STOCK_MENU_PROP,
 			    _("Properties..."));
+	applet_add_callback(applets_last->data, "help",
+			    GNOME_STOCK_PIXMAP_HELP,
+			    _("Help"));
 }
 
 static void
@@ -586,7 +594,8 @@ ask_about_launcher(char *file, PanelWidget *panel, int pos, gboolean exactpos)
 
 	gnome_dialog_set_default(GNOME_DIALOG(d),0);
 
-	gtk_widget_show_all(d);
+	gtk_widget_show_all (d);
+	panel_set_dialog_layer (d);
 }
 
 void
