@@ -1,5 +1,6 @@
 /* Gnome panel: Initialization routines
- * (C) 1997 the Free Software Foundation
+ * (C) 1997,1998,1999,2000 the Free Software Foundation
+ * (C) 2000 Eazel, Inc.
  *
  * Authors: Federico Mena
  *          Miguel de Icaza
@@ -623,7 +624,7 @@ panel_destroy(GtkWidget *widget, gpointer data)
 }
 
 static void
-panel_applet_move(GtkWidget *panel,GtkWidget *widget, gpointer data)
+panel_applet_move(PanelWidget *panel, GtkWidget *widget, gpointer data)
 {
 	applets_to_sync = TRUE;
 }
@@ -631,7 +632,8 @@ panel_applet_move(GtkWidget *panel,GtkWidget *widget, gpointer data)
 static void
 panel_applet_draw(GtkWidget *panel, GtkWidget *widget, gpointer data)
 {
-	AppletInfo *info = gtk_object_get_data(GTK_OBJECT(widget), "applet_info");
+	AppletInfo *info = gtk_object_get_data(GTK_OBJECT(widget),
+					       "applet_info");
 
 	g_return_if_fail(info!=NULL);
 
@@ -647,7 +649,7 @@ panel_menu_get(PanelWidget *panel, PanelData *pd)
 	
 	pd->menu = create_panel_root_menu(panel, TRUE);
 	gtk_signal_connect(GTK_OBJECT(pd->menu), "deactivate",
-			   GTK_SIGNAL_FUNC(menu_deactivate),pd);
+			   GTK_SIGNAL_FUNC(menu_deactivate), pd);
 	return pd->menu;
 }
 
@@ -916,8 +918,9 @@ drop_urilist(PanelWidget *panel, int pos, char *urilist)
 
 		if(mimetype && !strncmp(mimetype, "image", sizeof("image")-1))
 			panel_widget_set_back_pixmap (panel, filename);
-		else if(mimetype
-			&& !strcmp(mimetype, "application/x-gnome-app-info"))
+		else if(mimetype &&
+			(strcmp(mimetype, "application/x-gnome-app-info")==0 ||
+			 strcmp(mimetype, "application/x-kde-app-info")==0))
 			load_launcher_applet(filename, panel, pos, TRUE);
 		else if(S_ISDIR(s.st_mode)) {
 			drop_menu(panel, pos, filename);
