@@ -13,17 +13,18 @@ void tile_rgb(guchar *dest, int dw, int dh, int offx, int offy, int drs,
 	      guchar *tile, int w, int h, int rowstride, int has_alpha);
 /* tile an art_pixbuf onto an rgb buffer*/
 void tile_rgb_pixbuf(guchar *dest, int dw, int dh, int offx, int offy, int drs,
-		     ArtPixBuf *pbuf, int scale_w, int scale_h);
+		     ArtPixBuf *pbuf, int scale_w, int scale_h, int rotate);
 
 /* just copied from pixbuf source */
 GdkPixbuf *my_gdk_pixbuf_rgb_from_drawable(GdkWindow *window);
 
-/* scale a w by h pixmap into a square of size 'size' */
-void make_scale_affine(double affine[], int w, int h, int size);
-
+/* scale a w by h pixmap into a square of size 'size', optionally rerurn
+   outw and outh */
+void make_scale_affine(double affine[], int w, int h, int size,
+		       int *outw, int *outh);
 #if 0
-void cutout_rgb(guchar *dest, int drs, guchar *src, int x, int y, int w, int h, int srs);
-void place_rgb(guchar *dest, int drs, guchar *src, int x, int y, int w, int h, int srs);
+void rgb_rotate270(guchar *dest, int drs, guchar *src, int w, int h, int srs);
+void rgba_rotate270(guchar *dest, int drs, guchar *src, int w, int h, int srs);
 #endif
 
 #endif /* _RGB_STUFF_H_ */
