@@ -1,6 +1,7 @@
 /*
  * GNOME panel swallow module.
- * (C) 1997 The Free Software Foundation
+ * (C) 1997,1998,1999,2000 The Free Software Foundation
+ * (C) 2000 Eazel, Inc.
  *
  * Author: George Lebl
  */
@@ -18,19 +19,18 @@
 #include "panel-include.h"
 #include "panel-widget.h"
 
+#include "xstuff.h"
+
 /* from gtkhandlebox.c */
 #define DRAG_HANDLE_SIZE 10
 
 GList *check_swallows = NULL;
 
-static int
-ignore_x_error(Display* d, XErrorEvent* e)
-{
-	fprintf(stderr, "ignore_x_error called\n");
-	return 0;
-}
+extern GlobalConfig global_config;
 
+extern GSList *applets_last;
 
+#if 0
 static int
 get_window_id(Window win, char *title, guint32 *wid)
 {
@@ -43,6 +43,7 @@ get_window_id(Window win, char *title, guint32 *wid)
 	int ret = FALSE;
 	int (*oldErrorHandler)(Display*, XErrorEvent*);
 
+	gdk_error_trap_push ();
 		
 	XQueryTree(GDK_DISPLAY(),
 		   win,
@@ -51,7 +52,6 @@ get_window_id(Window win, char *title, guint32 *wid)
 		   &children,
 		   &nchildren);
 
-	oldErrorHandler = XSetErrorHandler(ignore_x_error);
 	for(i=0;i<nchildren;i++) {
 		if (!XFetchName(GDK_DISPLAY(),
 				children[i],
@@ -63,18 +63,20 @@ get_window_id(Window win, char *title, guint32 *wid)
 				XFree(tit);
 				*wid = children[i];
 				ret = TRUE;
-				break;
+				break ;
 			}
 			XFree(tit);
 		}
 	}
-	XSetErrorHandler(oldErrorHandler);
+	gdk_flush();
+	gdk_error_trap_pop ();
 	for(i=0;!ret && i<nchildren;i++)
 		ret=get_window_id(children[i],title,wid);
 	if(children)
 		XFree(children);
 	return ret;
 }
+#endif
 
 static int
 socket_realized(GtkWidget *w, gpointer data)
@@ -82,13 +84,18 @@ socket_realized(GtkWidget *w, gpointer data)
 	Swallow *swallow = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_val_if_fail(swallow->title!=NULL,FALSE);
+	
+	gdk_error_trap_push ();
 
-	if(!get_window_id(GDK_ROOT_WINDOW(),swallow->title, &swallow->wid)) {
+	if(!get_window_id(GDK_ROOT_WINDOW(), swallow->title,
+			  &swallow->wid, TRUE)) {
 		check_swallows = g_list_prepend(check_swallows,swallow);
-		/*XSelectInput(GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			     SubstructureNotifyMask);*/
+		xstuff_reset_need_substructure();
 	} else
-		gtk_socket_steal(GTK_SOCKET(swallow->socket),swallow->wid);
+		gtk_socket_steal(GTK_SOCKET(swallow->socket), swallow->wid);
+
+	gdk_flush();
+	gdk_error_trap_pop ();
 
 	return FALSE;
 }
@@ -230,7 +237,8 @@ ask_about_swallowing(PanelWidget *panel, int pos, gboolean exactpos)
 
 	gtk_widget_grab_focus(title_e);
 
-	gtk_widget_show_all(d);
+	gtk_widget_show_all (d);
+	panel_set_dialog_layer (d);
 }
 
 static int
@@ -349,20 +357,23 @@ load_swallow_applet(char *path, char *params, int width, int height,
 	if(!register_toy(swallow->ebox, swallow, panel, pos,
 			 exactpos, APPLET_SWALLOW))
 		return;
-
+	applet_add_callback(applets_last->data, "help",
+			    GNOME_STOCK_PIXMAP_HELP,
+			    _("Help"));
 	if(path && *path) {
 		char *p = strrchr(path,'.');
+		GnomeDesktopEntry *item;
 		/*only if such a file exists and ends in a .desktop, should
 		  we try to launch it as such*/
-		if(p && strcmp(p,".desktop")==0 && g_file_exists(path)) {
-			GnomeDesktopEntry *item;
-			item = gnome_desktop_entry_load(path);
+		if(p &&
+		   (strcmp(p,".desktop")==0 ||
+		    strcmp(p,".kdelnk")==0) &&
+		   g_file_exists(path) &&
+		   (item = gnome_desktop_entry_load(path))) {
 			gnome_desktop_entry_launch(item);
 			gnome_desktop_entry_free(item);
 		} else {
-			char *s = g_strconcat("(true; ",path," &)",NULL);
-			system(s);
-			g_free(s);
+			gnome_execute_shell(NULL, path);
 		}
 	}
 }
